Mylli

# Simple Mailing Client
Mylli is a cli tool for instant emails.

*This tool relies on the [Sendgrid Service](http://sendgrid.com)*.
Sign up for free before you begin and obtain API Key



Paste the key from Sendgrid after Succeessful signup


Installation
>sudo -H pip3 install mylli

Setting API KEY (run in terminal)
> mylli configure 

Usage
```
   mylli send -> Send email
   mylli broadcast -> broadcast to mailing list
   mylli add -> add address to Mailing List
   mylli mailist -> View Mailist
   mylli configure -> set SendGrid APIKEY
```
